@@ -6,7 +6,7 @@ import aesara.tensor.random.basic as arb
 import numpy as np
 from aesara.graph.op import Op
 from aesara.raise_op import CheckAndRaise
-from aesara.tensor.slinalg import Cholesky, solve_lower_triangular
+from aesara.tensor.slinalg import Cholesky, solve_triangular
 from aesara.tensor.var import TensorVariable
 
 from aeppl.dists import DiracDelta, DiscreteMarkovChainFactory
@@ -231,7 +231,7 @@ def exponential_logprob(op, values, *inputs, **kwargs):
 def laplace_logprob(op, values, *inputs, **kwargs):
     (value,) = values
     mu, b = inputs[3:]
-    res = -at.log(2 * b) - at.abs_(value - mu) / b
+    res = -at.log(2 * b) - at.abs(value - mu) / b
     res = CheckParameterValue("b > 0")(res, at.all(at.gt(b, 0.0)))
     return res
 
@@ -344,17 +344,10 @@ def wald_logprob(op, values, *inputs, **kwargs):
 @_logprob.register(arb.WeibullRV)
 def weibull_logprob(op, values, *inputs, **kwargs):
     (value,) = values
-    alpha, beta = inputs[3:]
-    res = (
-        at.log(alpha)
-        - at.log(beta)
-        + (alpha - 1.0) * at.log(value / beta)
-        - at.pow(value / beta, alpha)
-    )
+    (c,) = inputs[3:]
+    res = at.log(c) + (c - 1.0) * at.log(value) - at.pow(value, c)
     res = at.switch(at.ge(value, 0.0), res, -np.inf)
-    res = CheckParameterValue("alpha > 0, beta > 0")(
-        res, at.all(at.gt(alpha, 0.0)), at.all(at.gt(beta, 0.0))
-    )
+    res = CheckParameterValue("c > 0")(res, at.all(at.gt(c, 0.0)))
     return res
 
 
@@ -586,13 +579,13 @@ def mvnormal_logprob(op, values, *inputs, **kwargs):
     # factor = {'f': 1E3, 'd': 1E6}
     # t = s.numpy_dtype.char.lower()
     # cond = factor[t] * np.finfo(t).eps
-    # eps = cond * at.max(at.abs_(s))
+    # eps = cond * at.max(at.abs(s))
     # n = s[at.gt(s, eps)]
 
     all_pos_definite = at.all(at.gt(cov_chol_diag, 0))
     cov_chol = at.switch(all_pos_definite, cov_chol, 1)
 
-    z_T = solve_lower_triangular(cov_chol, r.T).T
+    z_T = solve_triangular(cov_chol, r.T, lower=True).T
     quaddist = at.pow(z_T, 2).sum(axis=-1)
 
     logdet = at.sum(at.log(cov_chol_diag))
